{ config, pkgs, ... }:

{
  # Home Manager needs a bit of information about you and the paths it should
  # manage.
  home.username = "polygon";
  home.homeDirectory = "/home/polygon";

  # This value determines the Home Manager release that your configuration is
  # compatible with. This helps avoid breakage when a new Home Manager release
  # introduces backwards incompatible changes.
  #
  # You should not change this value, even if you update Home Manager. If you do
  # want to update the value, then make sure to first check the Home Manager
  # release notes.
  nixpkgs.config.allowUnfree = true;
  # The home.packages option allows you to install Nix packages into your
  # environment.
  home.packages = with pkgs; [
    rustup
    firefox
    thunderbird
    hexchat
    steam
    keepassxc
    syncthing
    kdeconnect
    htop
    nmap
    tmux
    hyfetch
    stremio
    spotify
    godot_4
  ];

  programs = {  
    neovim.enable = true;
    vscode = {
    enable = true;
    package = pkgs.vscodium;
    #extensions = with pkgs.vscode-extensions; [nix-ide rust-lang.rust-analyzer ];
    };
    zsh = {
      enable = true;
      enableAutosuggestions = true;
      oh-my-zsh = {
        enable = true;
	plugins = [
	"adb"
	"rust"
	"git"
	"common-aliases"
	];
	theme = "bira";
      };
    };
    kitty = {
      enable = true;
      shellIntegration.enableZshIntegration = true;
      theme = "Dark Pride";
    };
  };

  services = {
    syncthing = {
      enable = true;
      tray.enable = true;
    };

  };

  # Home Manager is pretty good at managing dotfiles. The primary way to manage
  # plain files is through 'home.file'.
  home.file = {
    # # Building this configuration will create a copy of 'dotfiles/screenrc' in
    # # the Nix store. Activating the configuration will then make '~/.screenrc' a
    # # symlink to the Nix store copy.
    # ".screenrc".source = dotfiles/screenrc;

    # # You can also set the file content immediately.
    # ".gradle/gradle.properties".text = ''
    #   org.gradle.console=verbose
    #   org.gradle.daemon.idletimeout=3600000
    # '';
  };

  # Home Manager can also manage your environment variables through
  # 'home.sessionVariables'. If you don't want to manage your shell through Home
  # Manager then you have to manually source 'hm-session-vars.sh' located at
  # either
  #
  #  ~/.nix-profile/etc/profile.d/hm-session-vars.sh
  #
  # or
  #
  #  /etc/profiles/per-user/polygon/etc/profile.d/hm-session-vars.sh
  #
  home.sessionVariables = {
    EDITOR = "nvim";
  };

  # Let Home Manager install and manage itself.
  programs.home-manager.enable = true;
  home.sessionVariables.TZ = "Europe/Berlin";
  home.stateVersion = "23.11";
}
